/***************************************************************************
 *                                                                         *
 *  Copyright 2012 LSI Corporation.  All rights reserved.                  *
 *                                                                         *
 *  This file is confidential and a trade secret of LSI Corp.  The         *
 *  receipt of or possession of this file does not convey any rights to    *
 *  reproduce or disclose its contents or to manufacture, use, or sell     *
 *  anything it may describe, in whole, or in part, without the specific   *
 *  written consent of LSI Corporation.                                    *
 *                                                                         *
 ***************************************************************************
 *
 *           Name:  ddriFault.h
 *          Title:  DDR IFAULT code Definitions
 *     Programmer:  craigc
 *  Creation Date:  17sept09
 *
 *
 * Description
 * ------------
 */

#ifndef DDRIFAULT_H_INCLUDED
#define DDRIFAULT_H_INCLUDED




/******************************************************************************
* DDR IFAULT code definitions 0x9000 - 0x9FFF
*******************************************************************************/
#define IFAULT_DDR_UNHANDLED_INTERRUPT                           (0x9000)       /* Encountered an unhandled interrupt. */

#ifndef DDRINIT_FAULT_UNKNOWN_MR2_SRT
#define DDRINIT_FAULT_UNKNOWN_MR2_SRT                            (0x9001)       /* Unknown Self-Refresh-Temperature (SRT) type for Mode Register 2 (MR2). */
#endif

#ifndef DDRINIT_FAULT_UNKNOWN_DIMM_TYPE
#define DDRINIT_FAULT_UNKNOWN_DIMM_TYPE                          (0x9002)       /* Unable to determine if DIMM is registered or not. */
#endif

#ifndef DDRINIT_FAULT_PS_MEM_CLK_CYCLE_CONV_ERROR
#define DDRINIT_FAULT_PS_MEM_CLK_CYCLE_CONV_ERROR                (0x9003)       /* DDR DIMM Serial Presence Detect (SPD) math overflow when converting to memory pico-second clock cycles. */
#endif

#ifndef DDRINIT_FAULT_NS_MEM_CLK_CYCLE_CONV_ERROR
#define DDRINIT_FAULT_NS_MEM_CLK_CYCLE_CONV_ERROR                (0x9004)       /* DDR DIMM Serial Presence Detect (SPD) math overflow when converting to memory nano-second clock cycles. */
#endif

#ifndef DDRINIT_FAULT_UNSUPPORTED_NUM_RANKS
#define DDRINIT_FAULT_UNSUPPORTED_NUM_RANKS                      (0x9005)       /* Only 1 or 2 ranks are supported at this time. */
#endif

#ifndef DDRINIT_FAULT_MC_CONFIG_UNSUPPORTED_NUM_RANKS
#define DDRINIT_FAULT_MC_CONFIG_UNSUPPORTED_NUM_RANKS            (0x9006)       /* Unsupported number of ranks. */
#endif

#ifndef DDRINIT_FAULT_UNSUPPORTED_MEM_SIZE
#define DDRINIT_FAULT_UNSUPPORTED_MEM_SIZE                       (0x9007)       /* Reserved: Unsupported memory size. */
#endif

#ifndef DDRINIT_FAULT_UNSUPPORTED_ECC_MODE
#define DDRINIT_FAULT_UNSUPPORTED_ECC_MODE                       (0x9008)       /* Unsupported ECC mode. */
#endif

#ifndef DDRINIT_FAULT_UNSUPPORTED_TCL
#define DDRINIT_FAULT_UNSUPPORTED_TCL                            (0x9009)       /* Unsupported TCL (CAS Latency). CL-desired is more than max-CL supported by hardware. */
#endif

#ifndef DDRINIT_FAULT_TCL_ERROR
#define DDRINIT_FAULT_TCL_ERROR                                  (0x900A)       /* Unsupported TCL. The value tCL is not 8 and not in Mode Register 0 (MR0). */
#endif

#ifndef DDRINIT_FAULT_HIGHER_CL_NOT_FOUND
#define DDRINIT_FAULT_HIGHER_CL_NOT_FOUND                        (0x900B)       /* Find CL: CL-desired not supported, no higher value found. */
#endif

#ifndef DDRINIT_FAULT_UNSUPPORTED_WRLAT
#define DDRINIT_FAULT_UNSUPPORTED_WRLAT                          (0x900C)       /* Reserved. Hardware does not support write latency. */
#endif

#ifndef DDRINIT_FAULT_MC_INT_STATUS_NON_ZERO
#define DDRINIT_FAULT_MC_INT_STATUS_NON_ZERO                     (0x900D)       /* Memory Controller (MC) interrupt status is non-zero. */
#endif

#ifndef DDRINIT_FAULT_DFI_WR_LVL_FAIL
#define DDRINIT_FAULT_DFI_WR_LVL_FAIL                            (0x900E)       /* Write-leveling failed. Unexpected state - equal number of 1'b0 and 1'b1 Sw-Lvl-Resp across all iterations. */
#endif

#ifndef DDRINIT_FAULT_DFI_WR_LVL_FAIL_NO_ONE
#define DDRINIT_FAULT_DFI_WR_LVL_FAIL_NO_ONE                     (0x900F)       /* Walked all write-leveling delays and never saw a one. */
#endif

#ifndef DDRINIT_FAULT_DFI_WR_LVL_FAIL_NO_ZERO
#define DDRINIT_FAULT_DFI_WR_LVL_FAIL_NO_ZERO                    (0x9010)       /* Walked all write-leveling delays and never saw a zero. */
#endif

#ifndef DDRINIT_FAULT_DFI_WR_LVL_FAIL_UNKNOWN_STATE
#define DDRINIT_FAULT_DFI_WR_LVL_FAIL_UNKNOWN_STATE              (0x9011)       /* Reserved. Write-leveling failed. */
#endif

#ifndef DDRINIT_FAULT_DFI_WR_LVL_FAIL_UNEXPECTED_VALUE
#define DDRINIT_FAULT_DFI_WR_LVL_FAIL_UNEXPECTED_VALUE           (0x9012)       /* Unexpected write-leveling value while reading PHY response. */
#endif

#ifndef DDRINIT_FAULT_DFI_GATE_TRAIN_FAIL
#define DDRINIT_FAULT_DFI_GATE_TRAIN_FAIL                        (0x9013)       /* Reserved. Gate training failed. */
#endif

#ifndef DDRINIT_FAULT_DFI_READ_LEVEL_FAIL
#define DDRINIT_FAULT_DFI_READ_LEVEL_FAIL                        (0x9014)       /* Reserved. Read-leveling failed. */
#endif

#ifndef DDRINIT_FAULT_DFI_RD_LVL_FAIL_NO_DELAY_RESP_NOT_ONE
#define DDRINIT_FAULT_DFI_RD_LVL_FAIL_NO_DELAY_RESP_NOT_ONE      (0x9015)       /* Read-leveling failed. Response with no delay must be a one. */
#endif

#ifndef DDRINIT_FAULT_DFI_RD_LVL_FAIL_POS_EDGE_NO_ZERO_RESP
#define DDRINIT_FAULT_DFI_RD_LVL_FAIL_POS_EDGE_NO_ZERO_RESP      (0x9016)       /* Read-leveling failed. No 0 responses found on positive edge.. */
#endif

#ifndef DDRINIT_FAULT_DFI_RD_LVL_FAIL_POS_EDGE_NO_ONE_RESP
#define DDRINIT_FAULT_DFI_RD_LVL_FAIL_POS_EDGE_NO_ONE_RESP       (0x9017)       /* Read-leveling failed. No 1 responses found on positive edge. */
#endif

#ifndef DDRINIT_FAULT_DFI_RD_LVL_FAIL_DP_MISMATCH
#define DDRINIT_FAULT_DFI_RD_LVL_FAIL_DP_MISMATCH                (0x9018)       /* Read-leveling failed. One of the DP responses did not match. */
#endif

#ifndef DDRINIT_FAULT_DFI_RD_LVL_FAIL_INCORRECT_DP_WIGGLE
#define DDRINIT_FAULT_DFI_RD_LVL_FAIL_INCORRECT_DP_WIGGLE        (0x9019)       /* Read-leveling failed. Either one or all DP responses must wiggle. */
#endif

#ifndef DDRINIT_FAULT_DFI_RD_LVL_FAIL_NO_DELAY_RESP_NOT_ZERO
#define DDRINIT_FAULT_DFI_RD_LVL_FAIL_NO_DELAY_RESP_NOT_ZERO     (0x901A)       /* Read-leveling failed. Response at delay of zero must be a zero. */
#endif

#ifndef DDRINIT_FAULT_DFI_RD_LVL_FAIL_DELAY_EXHAUSTED
#define DDRINIT_FAULT_DFI_RD_LVL_FAIL_DELAY_EXHAUSTED            (0x901B)       /* Read-leveling failed. Cannot attempt further read-leveling. */
#endif

#ifndef DDRINIT_FAULT_DFI_RD_LVL_FAIL_NEG_EDGE_NO_ONE_RESP
#define DDRINIT_FAULT_DFI_RD_LVL_FAIL_NEG_EDGE_NO_ONE_RESP       (0x901C)       /* Read-leveling failed. No 1 responses found on negative edge. */
#endif

#ifndef DDRINIT_FAULT_DFI_RD_LVL_FAIL_NEG_EDGE_NO_ZERO_RESP
#define DDRINIT_FAULT_DFI_RD_LVL_FAIL_NEG_EDGE_NO_ZERO_RESP      (0x901D)       /* Read-leveling failed. No 0 response found on negative edge. */
#endif

#ifndef DDRINIT_FAULT_DFI_RD_LVL_FAIL_POS_EDGE_NIBBLE_MISMATCH
#define DDRINIT_FAULT_DFI_RD_LVL_FAIL_POS_EDGE_NIBBLE_MISMATCH   (0x901E)       /* Read-leveling failed. Nibble mismatch on positive edge. */
#endif

#ifndef DDRINIT_FAULT_DFI_RD_LVL_FAIL_NEG_EDGE_NIBBLE_MISMATCH
#define DDRINIT_FAULT_DFI_RD_LVL_FAIL_NEG_EDGE_NIBBLE_MISMATCH   (0x901F)       /* Read-leveling failed. Nibble mismatch on negative edge. */
#endif

#ifndef DDRINIT_FAULT_UNKNWON_RTT_NOM
#define DDRINIT_FAULT_UNKNWON_RTT_NOM                            (0x9020)       /* Unknown RTT (nominal) setting. */
#endif

#ifndef DDRINIT_FAULT_UNKNWON_RTT_NOM_TO_SET_IN_MR1
#define DDRINIT_FAULT_UNKNWON_RTT_NOM_TO_SET_IN_MR1              (0x9021)       /* DDRIF error. Unknown RTT (nominal) setting for Mode Register 1 (MR1). */
#endif

#ifndef DDRINIT_FAULT_UNKNOWN_RTT_RW
#define DDRINIT_FAULT_UNKNOWN_RTT_RW                             (0x9022)       /* Unknown RTT_WR (write) setting. */
#endif

#ifndef DDRINIT_FAULT_UNKNOWN_RTT_RW_TO_SET_IN_MR2
#define DDRINIT_FAULT_UNKNOWN_RTT_RW_TO_SET_IN_MR2               (0x9023)       /* DDRIF ERROR. Unknown RTT_WR (write) setting for Mode Register 2 (MR2). */
#endif

#ifndef DDRINIT_FAULT_UNSUPPORTED_CS_MAP
#define DDRINIT_FAULT_UNSUPPORTED_CS_MAP                         (0x9024)       /* Unsupported number of bits asserted in the chip-select map. */
#endif

#ifndef DDRINIT_FAULT_UNSUPPORTED_WIDTH
#define DDRINIT_FAULT_UNSUPPORTED_WIDTH                          (0x9025)       /* Unsupported DIMM module width. */
#endif

#ifndef DDRINIT_FAULT_UNSUPPORTED_SDRAM_DEV_WIDTH
#define DDRINIT_FAULT_UNSUPPORTED_SDRAM_DEV_WIDTH                (0x9026)       /* Unsupported SPD module organization. */
#endif

#ifndef DDRINIT_FAULT_UNSUPPORTED_BUS_WIDTH
#define DDRINIT_FAULT_UNSUPPORTED_BUS_WIDTH                      (0x9027)       /* Unsupported SPD module memory bus width. */
#endif

#ifndef DDRINIT_FAULT_UNSUPPORTED_MEM_FREQ
#define DDRINIT_FAULT_UNSUPPORTED_MEM_FREQ                       (0x9028)       /* Unsupported memory module frequency. */
#endif

#ifndef DDRINIT_FAULT_GATE_TRAINING_STYLE
#define DDRINIT_FAULT_GATE_TRAINING_STYLE                        (0x9029)       /* Reserved. Gate training failed. */
#endif

#ifndef DDRINIT_FAULT_UNSUPPORTED_RANK
#define DDRINIT_FAULT_UNSUPPORTED_RANK                           (0x902A)       /* Unsupported rank number. */
#endif

#ifndef DDRINIT_FAULT_READ_LEVELING_STYLE
#define DDRINIT_FAULT_READ_LEVELING_STYLE                        (0x902B)       /* Reserved. Invalid read-latency style. */
#endif

#ifndef DDRINIT_FAULT_READ_LEVELING_STYLE_2
#define DDRINIT_FAULT_READ_LEVELING_STYLE_2                      (0x902C)       /* Reserved. Invalid read-latency style. */
#endif

#ifndef DDRINIT_FAULT_UNSUPPORTED_DFI_RL
#define DDRINIT_FAULT_UNSUPPORTED_DFI_RL                         (0x902D)       /* Reserved. Unsupported DFI read-leveling. */
#endif

#ifndef DDRINIT_FAULT_WL_UNKNOWN_STATE
#define DDRINIT_FAULT_WL_UNKNOWN_STATE                           (0x902E)       /* Reserved. Unsupported write-leveling state. */
#endif

#ifndef DDRINIT_FAULT_WL_STYLE
#define DDRINIT_FAULT_WL_STYLE                                   (0x902F)       /* Reserved. Unsupported write-leveling style. */
#endif

#ifndef DDRINIT_FAULT_UNSUPPORTED_DQ_DELAYS
#define DDRINIT_FAULT_UNSUPPORTED_DQ_DELAYS                      (0x9030)       /* Reserved. Unsupported DQ delays. */
#endif

#ifndef DDRINIT_FAULT_UNSUPPORTED_XFER_SIZE
#define DDRINIT_FAULT_UNSUPPORTED_XFER_SIZE                      (0x9031)       /* Unsupported transfer size. Size is too large. */
#endif

#ifndef DDRINIT_FAULT_WLA_UNSUPPORTED_DELAY
#define DDRINIT_FAULT_WLA_UNSUPPORTED_DELAY                      (0x9032)       /* WLA ECC has failed because the delay is beyond the range of the delay line. */
#endif

#ifndef DDRINIT_FAULT_WLA_DELAY_OUT_OF_RANGE
#define DDRINIT_FAULT_WLA_DELAY_OUT_OF_RANGE                     (0x9033)       /* WLA has failed because the delay is beyond the range of the delay line. */
#endif

#ifndef DDRINIT_FAULT_UNKNOWN_SPD_VOLTAGE
#define DDRINIT_FAULT_UNKNOWN_SPD_VOLTAGE                        (0x9034)       /* Unknown supplied SPD voltage. */
#endif

#ifndef DDRINIT_FAULT_UNSUPPORTED_SPD_TABLE_NUM
#define DDRINIT_FAULT_UNSUPPORTED_SPD_TABLE_NUM                  (0x9035)       /* Unsupported SPD table number. */
#endif

#ifndef DDRINIT_FAULT_X4_NOT_SUPPORTED
#define DDRINIT_FAULT_X4_NOT_SUPPORTED                           (0x9036)       /* x4 devices are not supported. */
#endif

#ifndef DDRINIT_FAULT_WLA_DELAY_MISMATCH
#define DDRINIT_FAULT_WLA_DELAY_MISMATCH                         (0x9037)       /* Write-leveling upper and lower nibble are not equal. */
#endif

#ifndef DDRINIT_FAULT_WLA_DATA_LANE_DELAY_MISMATCH
#define DDRINIT_FAULT_WLA_DATA_LANE_DELAY_MISMATCH               (0x9038)       /* DQ data nibble delays are different within section. */
#endif

#ifndef DDRINIT_FAULT_WLA_ECC_LANE_DELAY_MISMATCH
#define DDRINIT_FAULT_WLA_ECC_LANE_DELAY_MISMATCH                (0x9039)       /* DQ ECC nibble delays are different within section. */
#endif

#ifndef DDRINIT_FAULT_INCORRECT_SPD_VERSION
#define DDRINIT_FAULT_INCORRECT_SPD_VERSION                      (0x903A)       /* Unsupported JEDEC SPD revision; only production values are supported. */
#endif

#ifndef DDRINIT_FAULT_PREAMBLE_FAILURE
#define DDRINIT_FAULT_PREAMBLE_FAILURE                           (0x903B)       /* Unable to find the DQS preamble on one or more lanes. */
#endif

#ifndef DDRINIT_FAULT_SING_CECC_FAIL_UNEXPECTED_BIT_SET
#define DDRINIT_FAULT_SING_CECC_FAIL_UNEXPECTED_BIT_SET          (0x903C)       /* Unexpected bits are set. Memory controller ECC single-bit, correctable error detected. */
#endif

#ifndef DDRINIT_FAULT_SINGLE_CECC_SCRUB_FAILURE
#define DDRINIT_FAULT_SINGLE_CECC_SCRUB_FAILURE                  (0x903D)       /* Unexpected bits are set. Memory controller ECC single-bit, correctable error detected. */
#endif

#ifndef DDRINIT_FAULT_SING_UECC_FAIL_UNEXPECTED_BIT_SET
#define DDRINIT_FAULT_SING_UECC_FAIL_UNEXPECTED_BIT_SET          (0x903E)       /* Unexpected bits are set. Memory controller ECC single-bit, uncorrectable error detected. */
#endif

#ifndef DDRINIT_FAULT_SING_UECC_FAILURE
#define DDRINIT_FAULT_SING_UECC_FAILURE                          (0x903F)       /* Unexpected bits are set. Data corruption has occurred and unable to scrub the memory to fix this. */
#endif

#ifndef DDRINIT_FAULT_MULTI_CECC_UNEXPECTED_BIT_SET
#define DDRINIT_FAULT_MULTI_CECC_UNEXPECTED_BIT_SET              (0x9040)       /* Unexpected bits are set. Memory controller ECC many-bit, correctable error detected. */
#endif

#ifndef DDRINIT_FAULT_MULTI_CECC_FAILURE
#define DDRINIT_FAULT_MULTI_CECC_FAILURE                         (0x9041)       /* Unexpected bits are set. Data corruption has occurred and unable to scrub the memory to fix this. */
#endif

#ifndef DDRINIT_FAULT_MULTI_CECC_SCRUB_FAILURE
#define DDRINIT_FAULT_MULTI_CECC_SCRUB_FAILURE                   (0x9042)       /* Unexpected bits are set. Data corruption has occurred and unable to scrub the memory to fix this. */
#endif

#ifndef DDRINIT_FAULT_MULTI_UECC_UNEXPECTED_BIT_SET
#define DDRINIT_FAULT_MULTI_UECC_UNEXPECTED_BIT_SET              (0x9043)       /* Unexpected bits are set. Memory controller ECC many-bit, un-correctable error detected. */
#endif

#ifndef DDRINIT_FAULT_MULTI_UECC_FAILURE
#define DDRINIT_FAULT_MULTI_UECC_FAILURE                         (0x9044)       /* Unexpected bits are set. Data corruption has occurred and unable to scrub the memory to fix this. */
#endif

#ifndef DDRINIT_FAULT_CMD_CHANNEL_ECC_FAILURE
#define DDRINIT_FAULT_CMD_CHANNEL_ECC_FAILURE                    (0x9045)       /* Unexpected bits are set. Memory controller ECC command channel error detected. */
#endif

#ifndef DDRINIT_FAULT_CMD_CHANNEL_ECC_UNEXPECTED_BIT_SET
#define DDRINIT_FAULT_CMD_CHANNEL_ECC_UNEXPECTED_BIT_SET         (0x9046)       /* Unexpected bits are set. Memory controller ECC command channel error detected. */
#endif

#ifndef DDRINIT_FAULT_DATA_CHANNEL_ECC_FAILURE
#define DDRINIT_FAULT_DATA_CHANNEL_ECC_FAILURE                   (0x9047)       /* Unexpected bits are set. Memory controller ECC command channel error detected. */
#endif

#ifndef DDRINIT_FAULT_DATA_CHANNEL_ECC_UNEXPECTED_BIT_SET
#define DDRINIT_FAULT_DATA_CHANNEL_ECC_UNEXPECTED_BIT_SET        (0x9048)       /* Unexpected bits are set. Memory controller ECC data channel error detected. */
#endif

#ifndef DDRINIT_FAULT_ECC_SING_OOA_UNEXPECTED_BIT_SET
#define DDRINIT_FAULT_ECC_SING_OOA_UNEXPECTED_BIT_SET            (0x9049)       /* Unexpected bits are set. Memory controller out-of-address range single error detected. */
#endif

#ifndef DDRINIT_FAULT_SING_OOA_ECC_FAILURE
#define DDRINIT_FAULT_SING_OOA_ECC_FAILURE                       (0x904A)       /* Unexpected bits are set. Memory controller out-of-address range single error detected. */
#endif

#ifndef DDRINIT_FAULT_ECC_MULTI_OOA_UNEXPECTED_BIT_SET
#define DDRINIT_FAULT_ECC_MULTI_OOA_UNEXPECTED_BIT_SET           (0x904B)       /* Unexpected bits are set. Memory controller out-of-address range many errors detected. */
#endif

#ifndef DDRINIT_FAULT_MULTI_OOA_ECC_FAILURE
#define DDRINIT_FAULT_MULTI_OOA_ECC_FAILURE                      (0x904C)       /* Unexpected bits are set. Memory controller out-of-address range many errors detected. */
#endif

#ifndef DDRINIT_FAULT_ECC_FAILURE
#define DDRINIT_FAULT_ECC_FAILURE                                (0x904D)       /* No interrupt status (int-stat) bits were set, bogus memory controller interrupt detected. */
#endif

#ifndef DDRINIT_FAULT_UNKNOWN_ECC_MODE
#define DDRINIT_FAULT_UNKNOWN_ECC_MODE                           (0x904E)       /* Unknown memory controller ECC mode. */
#endif

#ifndef DDRINIT_FAULT_UNKNOWN_ECC_MODE_TO_SET
#define DDRINIT_FAULT_UNKNOWN_ECC_MODE_TO_SET                    (0x904F)       /* Unknown ECC mode. */
#endif

#ifndef DDRINIT_FAULT_UNKNOWN_ECC_LANE
#define DDRINIT_FAULT_UNKNOWN_ECC_LANE                           (0x9050)       /* Reserved. Unknown ECC lane. */
#endif

#ifndef DDRINIT_FAULT_UNKNOWN_DP_NUM
#define DDRINIT_FAULT_UNKNOWN_DP_NUM                             (0x9051)       /* Unknown data path number specified. */
#endif

#ifndef DDRINIT_FAULT_UNSUPPORTED_NUM_BANKS
#define DDRINIT_FAULT_UNSUPPORTED_NUM_BANKS                      (0x9052)       /* Only SDRAMs with 8 banks are supported for DDR3. */
#endif

#ifndef DDRINIT_FAULT_SW_LVL_NOT_COMPLETE_DURING_START
#define DDRINIT_FAULT_SW_LVL_NOT_COMPLETE_DURING_START           (0x9053)       /* Software leveling action has not completed. */
#endif

#ifndef DDRINIT_FAULT_SW_LVL_NOT_COMPLETE_DURING_LOAD
#define DDRINIT_FAULT_SW_LVL_NOT_COMPLETE_DURING_LOAD            (0x9054)       /* Software leveling action has not completed. */
#endif

#ifndef DDRINIT_FAULT_SW_LVL_NOT_COMPLETE_DURING_EXIT
#define DDRINIT_FAULT_SW_LVL_NOT_COMPLETE_DURING_EXIT            (0x9055)       /* Software leveling action has not completed. */
#endif

#ifndef DDRINIT_FAULT_UNKNOWN_SECTION_NUM
#define DDRINIT_FAULT_UNKNOWN_SECTION_NUM                        (0x9056)       /* Unknown section number. */
#endif

#ifndef DDRINIT_FAULT_UNKNOWN_REVISION
#define DDRINIT_FAULT_UNKNOWN_REVISION                           (0x9057)       /* Reserved. */
#endif

#ifndef DDRINIT_FAULT_UNKNOWN_ODS_FOR_MR1
#define DDRINIT_FAULT_UNKNOWN_ODS_FOR_MR1                        (0x9058)       /* Unknown output drive strength (ODS) type for Mode Register 1 (MR1). */
#endif

#ifndef DDRINIT_FAULT_UNKNOWN_QOFF_FOR_MR1
#define DDRINIT_FAULT_UNKNOWN_QOFF_FOR_MR1                       (0x9059)       /* Unknown Qoff type for Mode Register 1 (MR1). */
#endif

#ifndef DDRINIT_FAULT_UNKNOWN_SYNDROME_STATE
#define DDRINIT_FAULT_UNKNOWN_SYNDROME_STATE                     (0x905A)       /* Unknown syndrome decode state. */
#endif

#ifndef DDRINIT_FAULT_MEMPORT_ERR
#define DDRINIT_FAULT_MEMPORT_ERR                                (0x905B)       /* Memory port error. Parity or DIMM temperature sensor event. */
#endif

#ifndef DDRINIT_FAULT_SPD_CRC_ERROR
#define DDRINIT_FAULT_SPD_CRC_ERROR                              (0x905C)       /* CRC check for SPD data failed. */
#endif

#ifndef DDRINIT_FAULT_SPD_UNDEFINED_VALUE
#define DDRINIT_FAULT_SPD_UNDEFINED_VALUE                        (0x905D)       /* Zero is unsupported in byte 0 of SPD data. */
#endif

#ifndef DDRINIT_FAULT_SPD_UNKNOWN_VALUE
#define DDRINIT_FAULT_SPD_UNKNOWN_VALUE                          (0x905E)       /* Undefined is unsupported in byte 0 of SPD data. */
#endif

#ifndef DDRINIT_FAULT_SPD_UNKNOWN_ADDR_DECODE_FOR_ROW
#define DDRINIT_FAULT_SPD_UNKNOWN_ADDR_DECODE_FOR_ROW            (0x905F)       /* Unknown SPD byte 5. SDRAM addressing decode for row bits. */
#endif

#ifndef DDRINIT_FAULT_SPD_UNKNOWN_ADDR_DECODE_FOR_COL
#define DDRINIT_FAULT_SPD_UNKNOWN_ADDR_DECODE_FOR_COL            (0x9060)       /* Unknown SPD byte 5. SDRAM addressing decode for column bits. */
#endif

#ifndef DDRINIT_FAULT_SPD_UNKNOWN_BANKS
#define DDRINIT_FAULT_SPD_UNKNOWN_BANKS                          (0x9061)       /* Unknown SPD byte 4. Unknown SDRAM banks. */
#endif

#ifndef DDRINIT_FAULT_SPD_ADDRESS_MIRROR_REG_DIMM
#define DDRINIT_FAULT_SPD_ADDRESS_MIRROR_REG_DIMM                (0x9062)       /* Unknown SPD byte 4. Unknown mirror register SDRAM banks. */
#endif

#ifndef DDRINIT_FAULT_WL_JITTER
#define DDRINIT_FAULT_WL_JITTER                                  (0x9063)       /* Reserved. Detected jitter for write-leveling. */
#endif

#ifndef DDRINIT_FAULT_ECC_LEVELING
#define DDRINIT_FAULT_ECC_LEVELING                               (0x9064)       /* Reserved. */
#endif

#ifndef DDRINIT_FAULT_MC_INIT
#define DDRINIT_FAULT_MC_INIT                                    (0x9065)       /* Refesh cycles between zqcs commands larger than mask. */
#endif

#ifndef DDRINIT_FAULT_EXT_TEMP_NOT_SUPPORTED
#define DDRINIT_FAULT_EXT_TEMP_NOT_SUPPORTED                     (0x9066)       /* High temperature refresh rate selected, but extended Self-Refresh-Temperature (SRT) is not supported by DIMM. */
#endif

#ifndef DDRINIT_FAULT_UNKNOWN_ODS
#define DDRINIT_FAULT_UNKNOWN_ODS                                (0x9067)       /* Unknown DIMM Output-Drive-Strength (ODS) setting. */
#endif

#ifndef DDRINIT_FAULT_READ_FIFO_TRAIN_DFI_RL_CALC_FAIL
#define DDRINIT_FAULT_READ_FIFO_TRAIN_DFI_RL_CALC_FAIL           (0x9068)       /* Cannot convert mc-dfi-rl value of zero to phy-dfi-rl. */
#endif

#ifndef DDRINIT_FAULT_READ_FIFO_TRAIN_PHY_DFI_RL_OUT_OF_RANGE
#define DDRINIT_FAULT_READ_FIFO_TRAIN_PHY_DFI_RL_OUT_OF_RANGE    (0x9069)       /* Start-of-day DFI-RL value does not fit into PHY/MC regs. CAS value too large. */
#endif

#ifndef DDRINIT_FAULT_READ_FIFO_TRAIN_UNKNOWN_SWEEP_DIRECTION
#define DDRINIT_FAULT_READ_FIFO_TRAIN_UNKNOWN_SWEEP_DIRECTION    (0x906A)       /* Unknown sweep direction. */
#endif

#ifndef DDRINIT_FAULT_READ_FIFO_TRAIN_SWEEP_START_OUT_OF_RANGE
#define DDRINIT_FAULT_READ_FIFO_TRAIN_SWEEP_START_OUT_OF_RANGE   (0x906B)       /* Starting value for sweep is too high. It is larger than max-dfirl-delay. */
#endif

#ifndef DDRINIT_FAULT_READ_FIFO_TRAIN_TRANSFER_SIZE_ERROR
#define DDRINIT_FAULT_READ_FIFO_TRAIN_TRANSFER_SIZE_ERROR        (0x906C)       /* DFI RL training size larger than ddrinit-calibration-mem-size from iop. */
#endif

#ifndef DDRINIT_FAULT_READ_FIFO_TRAIN_PHY_RDLAT_ERROR
#define DDRINIT_FAULT_READ_FIFO_TRAIN_PHY_RDLAT_ERROR            (0x906D)       /* An error occurred during read FIFO training. */
#endif

#ifndef DDRINIT_FAULT_READ_FIFO_TRAIN_ALG_ASSUMPTION_FAIL
#define DDRINIT_FAULT_READ_FIFO_TRAIN_ALG_ASSUMPTION_FAIL        (0x906E)       /* Algorithm assumption failure. Initial sweep value must be in functional window to find edges. */
#endif

#ifndef DDRINIT_FAULT_READ_FIFO_TRAIN_RL_ZERO_ERROR
#define DDRINIT_FAULT_READ_FIFO_TRAIN_RL_ZERO_ERROR              (0x906F)       /* Unable to decrement read-leveling further. */
#endif

#ifndef DDRINIT_FAULT_READ_FIFO_TRAIN_UNEXPECTED_SWEEP_DIRECTION
#define DDRINIT_FAULT_READ_FIFO_TRAIN_UNEXPECTED_SWEEP_DIRECTION (0x9070)       /* Unexpected sweep direction. */
#endif

#ifndef DDRINIT_FAULT_READ_FIFO_TRAIN_UNEXPECTED_MAX_PHY_DFI_RL
#define DDRINIT_FAULT_READ_FIFO_TRAIN_UNEXPECTED_MAX_PHY_DFI_RL  (0x9071)       /* Unexpected max phy-dfi-rl value. It is larger than maximum defined value. */
#endif

#ifndef DDRINIT_FAULT_READ_FIFO_TRAIN_MIN_WORK_VALUE_ERROR
#define DDRINIT_FAULT_READ_FIFO_TRAIN_MIN_WORK_VALUE_ERROR       (0x9072)       /* Unable to find minimum value where everything worked. */
#endif

#ifndef DDRINIT_FAULT_READ_FIFO_TRAIN_DATA_FINAL_RESULT_ERROR
#define DDRINIT_FAULT_READ_FIFO_TRAIN_DATA_FINAL_RESULT_ERROR    (0x9073)       /* Data lanes training error. Final result did not pass. */
#endif

#ifndef DDRINIT_FAULT_READ_FIFO_TRAIN_ECC_FINAL_RESULT_ERROR
#define DDRINIT_FAULT_READ_FIFO_TRAIN_ECC_FINAL_RESULT_ERROR     (0x9074)       /* ECC lane error. Final result did not pass. */
#endif

#ifndef DDRINIT_FAULT_INVALID_PARAMETER_LP_MODE_ERROR
#define DDRINIT_FAULT_INVALID_PARAMETER_LP_MODE_ERROR            (0x9075)       /* The caller passed in an incorrect parameter to ddriSetupEntryLpMode*/
#endif

#ifndef DDRINIT_FAULT_WRITE_DATA_PARITY_FAILURE
#define DDRINIT_FAULT_WRITE_DATA_PARITY_FAILURE                  (0x9076)       /* Memory controller write data parity error detected. */
#endif

#ifndef DDRINIT_FAULT_WRITE_DATA_PARITY_UNEXPECTED_BIT_SET
#define DDRINIT_FAULT_WRITE_DATA_PARITY_UNEXPECTED_BIT_SET       (0x9077)       /* Unexpected bits are set. Memory controller write data parity error detected.*/
#endif

#endif  /* if not defined ddrifault-h-included */

